控方证人 (豆瓣)
Description: 控方证人电影简介和剧情介绍,控方证人影评、图片、预告片、影讯、论坛、在线购票
Keywords: 控方证人,Witness for the Prosecution,控方证人影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.20豆瓣电影Top250

# 控方证人 Witness for the Prosecution (1957)

更新描述或海报

导演: 比利·怀尔德
编剧: 阿加莎·克里斯蒂 / 比利·怀尔德 / 哈里·库尼兹
主演: 泰隆·鲍华 / 玛琳·黛德丽 / 查尔斯·劳顿 / 埃尔莎·兰彻斯特 / 约翰·威廉姆斯 / 亨利·丹尼尔 / 伊安·沃尔夫 / 托林·撒切尔 / 诺玛·威登 / 尤娜·奥康纳 / 茹塔·李
类型: 剧情 / 悬疑 / 犯罪
制片国家/地区: 美国
语言: 英语 / 德语
上映日期: 1957-12-17(美国)
片长: 116分钟
又名: 雄才伟略 / 情妇
IMDb: tt0051201
豆瓣评分
引用
9.6
505649人评价
5星
82.3%
4星
16.0%
3星
1.6%
2星
0.1%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
10.0
2人评价
好于 99% 悬疑片
好于 99% 犯罪片
想看 看过
评价:
推荐

## 控方证人的剧情简介 · · · · · ·

伦敦著名刑案辩护律师韦菲爵士（查尔斯•劳顿 Charles Laughton 饰）接受了心脏病治疗，但是身体依旧虚弱，第一天回家休养，护士一直严厉监督他服药，并杜绝烟酒。管家为了便于上楼，还专门为他修了电梯。但是，种种关心照顾，对于这位桀骜不驯、牙尖嘴利的大律师根本不起作用，反倒是一纸诉状令他倍感兴奋。律师梅休和当事人沃尔（泰隆•鲍华 Tyrone Power饰）登门拜访，请他出山打官司。原来，沃尔结识了富婆，两人相见甚欢，虽然仆人对他发明的打蛋器充满鄙夷，但是富婆却对他充满爱意，甚至为他修改了遗嘱，把8万英镑留给了他。然而，富婆却惨遭毒手。于是，沃尔成为警方的头号嫌疑犯。他的唯一证人是妻子克里斯汀（玛琳•黛德丽 Marlene Dietrich饰），然而后者登门时的冷漠与淡定，令韦菲爵士怀疑这其中另有隐情。在扑朔迷离的案件背后，隐藏着一个个环环相扣... (展开全部) 伦敦著名刑案辩护律师韦菲爵士（查尔斯•劳顿 Charles Laughton 饰）接受了心脏病治疗，但是身体依旧虚弱，第一天回家休养，护士一直严厉监督他服药，并杜绝烟酒。管家为了便于上楼，还专门为他修了电梯。但是，种种关心照顾，对于这位桀骜不驯、牙尖嘴利的大律师根本不起作用，反倒是一纸诉状令他倍感兴奋。律师梅休和当事人沃尔（泰隆•鲍华 Tyrone Power饰）登门拜访，请他出山打官司。原来，沃尔结识了富婆，两人相见甚欢，虽然仆人对他发明的打蛋器充满鄙夷，但是富婆却对他充满爱意，甚至为他修改了遗嘱，把8万英镑留给了他。然而，富婆却惨遭毒手。于是，沃尔成为警方的头号嫌疑犯。他的唯一证人是妻子克里斯汀（玛琳•黛德丽 Marlene Dietrich饰），然而后者登门时的冷漠与淡定，令韦菲爵士怀疑这其中另有隐情。在扑朔迷离的案件背后，隐藏着一个个环环相扣、不可告人的秘密……
本片改编自阿加莎•克里斯蒂同名小说。 ©豆瓣

## 控方证人的演职员 · · · · · · ( 全部 56 )

- 比利·怀尔德 导演
- 泰隆·鲍华 饰 Leonard Vole
- 玛琳·黛德丽 饰 Christine
- 查尔斯·劳顿 饰 Sir Wilfrid Roberts
- 埃尔莎·兰彻斯特 饰 Miss Plimsoll
- 约翰·威廉姆斯 饰 Brogan-Moore

## 控方证人的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片759 · 添加 )

## 控方证人的获奖情况 · · · · · · ( 全部 )

- 第30届奥斯卡金像奖
- 最佳影片(提名)
- 小阿瑟·霍恩布洛

- 第30届奥斯卡金像奖
- 最佳导演(提名)
- 比利·怀尔德

- 第15届金球奖
- 电影类 最佳剧情片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  看不见的客人

  控方证人

  记忆碎片

  禁闭岛

  电话谋杀案

  追随

  十二怒汉

  致命魔术

  非常嫌疑犯

  利刃出鞘

我要写短评

## 控方证人的短评 · · · · · · ( 全部 148083 条 )

热门 / 最新 / 好友

### 3588 有用 Q。 看过 2011-07-10 22:55:56

无论是剧本、导演还是个人表演，几乎都无可挑剔。机智的台词和精彩的法庭辩论，十足精彩！即便在结局前猜到了最终结果也并不会让电影在精彩程度上有丝毫削减。btw,电影最后提示请勿剧透我还真是头一会见。★★★★☆

### 3614 有用 丁一 看过 2009-11-30 09:10:01

律师三寸舌，妇人宫心计，两者皆不敌，最坏男人心，花心郎算尽太聪明，反算了戚戚性命

### 5493 有用 内陆飞鱼 看过 2013-10-03 14:55:05

当结尾旁白说“影院友情提示，为了保证您没有看过这部电影的朋友，有机会获得更大观影乐趣，请您不要像任何人透露这部电影的结局”时，真爽，这个电影真是骗足了同情心，飚足了演技，压足了节奏，然后唰唰大释放。一场英国男人和德国女人之间爱情与欺骗的故事，现在才看，对不起比利·怀尔德老人家。

### 9070 有用 沉歌 看过 2012-02-08 13:29:42

男人贪心，女人贪爱

### 809 有用 蚂蚁没问题 看过 2011-07-10 14:00:28

演的不错，但是结局也没有说的那么玄乎吧？多读几本阿婆的书，这样的结局还不是手到擒来。

> 更多短评 148083条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 CoCo陶可可 看过 2020-04-06 01:45:47

2020，014。强烈推荐！

我要写影评

## 控方证人的影评 · · · · · · ( 全部 1145 条 )

热门 / 最新 / 好友
赱馬觀♣ 2008-01-23 18:16:27

## 阿加莎·克里斯蒂作品改编。比利·怀德经典

克里斯蒂的小说很不容易改编成影视作品。因为女作家为了增加小说悬念，在书中通常会设计很多疑似涉案人物。而这些人当中，真正的凶手只有一两位（也许东方快车是个例外），其他的大部分的作用仅仅是迷惑读者的障眼法而已。但这样的故事模式，一旦被电影具象化，就产生了希区柯... (展开)
2869 153 250回应 收起
豌豆 2009-07-10 18:54:20

## 劳顿的胖，黛德丽的大腿

马克吐温在他自己某本小说序言中说了类似以下的话，不许任何人在我的这本小说中寻找意义、揣摩本人的思想境界、把它挖得伤筋动骨。作者跳出自己的作品，跑出来通知读者怎么看才正确的，还有一个美国人比利怀特。他的这出《控方证人》的前前后后都缀满了自己的话，他在海报上写... (展开)
855 68 34回应 收起
大夏龙雀 2010-03-14 14:22:18

## 照亮黛德丽的脸

这篇影评可能有剧透

控方证人：照亮黛德丽的脸 1957年的《控方证人》，又名《原告的证人》、《雄才伟略》，是好莱坞天才导演比利•怀德改编自天才侦探小说作家阿加莎•克里斯蒂的同名剧本，男女主演是好莱坞红极一时的泰隆•鲍华和玛林•黛德丽。在演员表上，还值得一提的是扮演辩方律师，... (展开)
612 90 43回应 收起
我就是我 2009-12-28 16:53:45

## 过程比结果更令人震惊

经典之所以成为经典，最重要的在于其顽强的生命力。这部拍摄于1957年的法律题材电影，在后来不计其数类似题材故事影视作品的映衬之下，非但没有丝毫褪色，反而显得更加惊艳。我边看片子边想，这样一个被后世多次重复的故事是怎样被呈现得如此精彩的？昨晚刚看完此片的我目前还... (展开)
279 35 42回应 收起
瓜牛 2014-12-11 23:24:28

## 婊子的证词更有效

看完这部经典，想起了前一段非行导演的《全民目击》，时隔半个多世纪，容易被常识和情绪左右的公众或者（陪审团）依然是这类涉及司法的电影所要讽刺的对象，就像克里斯汀娜所说“公众更愿意相信一个浪荡的婊子在说谎，而不愿相信一个贤惠的妻子在为丈夫作证”，因此，为了爱人... (展开)
242 20 17回应 收起
沁沁 2017-03-21 19:35:56

## 细细品味老电影的味道，真的很用心

这是一部很值得推敲的电影,在细节的处理上真的很用心： 患有心脏病的高级出庭律师刚出院,唠唠叨叨的护士陪着,自己不胜其烦,但又无可奈何.护士在车上说自己当初差点嫁给一个律师,结尾的时候,护士挽着律师的手走出法庭,不知道是不有什么暗示。 护士从手杖里没收了雪茄,律师看到助... (展开)
108 6 7回应 收起
isabelle 2009-04-08 20:32:50

## 有剧透慎入！！！

这篇影评可能有剧透

原著小说 原告的证人 梅亨先生扶正了他的夹鼻眼镜，用他特有的略微干燥的咳嗽清了清嗓子，然后，再看看坐在他对面的男人，那个被指控犯了故意杀人罪的男人。 梅亨先生是一个小个子的男人，外表雅致整洁，不穿那些浮华的衣服，长着一双非常机敏而又锐利的灰眼睛。怎么看，... (展开)
127 17 7回应 收起
潘霄 M.D. 2018-08-16 16:47:31 #在比利·怀德的作品中，《控方证人》的剧作表现处于什么水平？

## 反转再反转，神级高潮

这篇影评可能有剧透

这部电影的精彩之处在于两点： 1、极为精彩的剧情，反转再反转。 2、演员的神级表演。 剧情的精彩难以言表，在此记录： 一个知名老律师刚出院就有穷苦大叔前来求助，相好的寡妇被害，凶手真的不是我！但很多证据都对他极为不利，遗嘱、寡妇的女仆甚至他自己的太太都不愿意作证... (展开)
126 19 43回应 收起
爱你不解释 2018-05-19 23:18:43

## 控方证人简介

伦敦著名刑案辩护律师韦菲爵士（查尔斯•劳顿 Charles Laughton 饰）接受了心脏病治疗，但是身体依旧虚弱，第一天回家休养，护士一直严厉监督他服药，并杜绝烟酒。管家为了便于上楼，还专门为他修了电梯。但是，种种关心照顾，对于这位桀骜不驯、牙尖嘴利的大律师根本不起作... (展开)
59 13 1回应 收起

> 更多影评 1145篇

添加新讨论

## 讨论区 · · · · · ·

我反正真的从来没有怀疑过男主 | 来自趁 ง ง | 11 回应 | 2022-11-23 11:46:21
你有没有怀疑过男主，从何时开始的？ | 来自筱燕梓 | 257 回应 | 2022-11-21 23:27:23
我喜欢那个女管家 | 来自一 | 8 回应 | 2022-11-19 13:00:35
女主之前结过婚吗？前夫没有消息了？ | 来自安崎（已登基） | 1 回应 | 2022-11-17 23:11:33
评分过高了，7.6差不多 | 来自雲漾 | 4 回应 | 2022-11-14 19:38:29

> 去这部影片的讨论区（全部277条）

## 关于《控方证人》的问题 · · · · · · ( 全部46个 )

- 谁能告诉我为什么法庭的桌子上会出现一把刀子？ 13人回答
- 电影开头出现的镜片测试是什么原理？ 10人回答

> 全部46个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 咪咕视频 VIP免费观看
- 优酷视频 VIP免费观看
- 1905电影网 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 他们是高智商玩家 (中间元素)
- 【豆瓣五星电影集中营】(2/3) (影志)
- 桃桃推荐｜值得一看（209部） (桃桃林林)

## 谁在看这部电影 · · · · · ·

- Avocado
  1分钟前 看过
- 乐乐的自留地
  2分钟前 看过
- Sai
  3分钟前 想看

655248人看过 / 439973人想看

订阅控方证人的评论:
feed: rss 2.0